#ifndef NT2_INCLUDE_FUNCTIONS_ILOGB_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ILOGB_HPP_INCLUDED

#include <nt2/ieee/include/functions/ilogb.hpp>

#endif
